vector_potential_point_segment

Function vector_potential_point_segment 

pub fn vector_potential_point_segment(
    xyzp: (&[f64], &[f64], &[f64]),
    xyzfil: (&[f64], &[f64], &[f64]),
    dlxyzfil: (&[f64], &[f64], &[f64]),
    ifil: &[f64],
    out: (&mut [f64], &mut [f64], &mut [f64]),
) -> Result<(), &'static str>
Vector potential calculation for A-field contribution from many current filament segments to many observation points.

Uses filament midpoint as field source.

Arguments

  • xyzp: (m) Observation point coords, each length n
  • xyzfil: (m) Filament origin coords (start of segment), each length m
  • dlxyzfil: (m) Filament segment length deltas, each length m
  • ifil: (A) Filament current, length m
  • out: (V-s/m) ax, ay, az at observation points, each length n