pub trait Scalar:
Float
+ FromPrimitive
+ Copy
+ Clone
+ Default
+ Debug
+ PartialOrd
+ Add<Output = Self>
+ Sub<Output = Self>
+ Mul<Output = Self>
+ Div<Output = Self>
+ Send
+ Sync
+ 'static {
const ZERO: Self;
const ONE: Self;
// Required methods
fn min_positive() -> Self;
fn to_f64(self) -> f64;
}Expand description
Scalar type shared by generic math, mesh, field, and FEM infrastructure.
Floating-point operations, including Float::min and Float::max, are
exposed through the Float supertrait.
Required Associated Constants
Required Methods
Sourcefn min_positive() -> Self
fn min_positive() -> Self
Return the smallest positive finite value for this scalar type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".